# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-01-13 01:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_provider', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='consumer',
            name='id',
        ),
        migrations.RemoveField(
            model_name='nonce',
            name='id',
        ),
        migrations.RemoveField(
            model_name='scope',
            name='id',
        ),
        migrations.RemoveField(
            model_name='token',
            name='id',
        ),
        migrations.AlterField(
            model_name='consumer',
            name='key',
            field=models.CharField(max_length=1024, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='consumer',
            name='secret',
            field=models.CharField(blank=True, max_length=1024),
        ),
        migrations.AlterField(
            model_name='nonce',
            name='consumer_key',
            field=models.CharField(max_length=1024),
        ),
        migrations.AlterField(
            model_name='nonce',
            name='key',
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='scope',
            name='name',
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='token',
            name='key',
            field=models.CharField(default='', max_length=32, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='token',
            name='secret',
            field=models.CharField(blank=True, max_length=1024, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from django.utils.translation import ugettext as _
from django.http import HttpResponseBadRequest

import oauth10a as oauth

from oauth_provider.utils import send_oauth_error

#INVALID_PARAMS_RESPONSE = send_oauth_error(oauth.Error(_('Invalid request parameters.')))
#INVALID_CONSUMER_RESPONSE = HttpResponseBadRequest('Invalid Consumer.')
#INVALID_SCOPE_RESPONSE = send_oauth_error(oauth.Error(_('You are not allowed to access this resource.')))
#COULD_NOT_VERIFY_OAUTH_REQUEST_RESPONSE = send_oauth_error(oauth.Error(_('Could not verify OAuth request.')))

def GetInvalidParamsResponse():
	return send_oauth_error(oauth.Error(_('Invalid request parameters.')))
def GetInvalidConsumerResponse():
	return HttpResponseBadRequest('Invalid Consumer.')
def GetInvalidScopeResponse():
	return send_oauth_error(oauth.Error(_('You are not allowed to access this resource.')))
def GetCouldNotVerifyOAuthRequestResponse():
	return send_oauth_error(oauth.Error(_('Could not verify OAuth request.')))




# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from rest_framework import authentication
from rest_framework import exceptions
from .decorators import DoOAuthCheck

class OAuthAuthentication(authentication.BaseAuthentication):
    """
    Allows access only to OAuth authenticated users.
    """

    def authenticate(self, request):
        if 'Authorization' not in request.META and 'HTTP_AUTHORIZATION' not in request.META:
            return None

        ok, err_view, token_user = DoOAuthCheck(request, None)
        if not ok:
            raise exceptions.AuthenticationFailed()

        return (token_user, None)




# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from rest_framework import permissions
from .decorators import DoOAuthCheck

class IsOAuth(permissions.BasePermission):
    """
    Allows access only to OAuth authenticated users.
    """

    def has_permission(self, request, view):
        ok, err_view = DoOAuthCheck(request, None, view)
        return ok




# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from django.db import models
from oauth_provider.compat import get_random_string
from oauth_provider.consts import SECRET_SIZE
import uuid

class TokenManager(models.Manager):
    def create_token(self, consumer, token_type, timestamp, scope,
            user=None, callback=None, callback_confirmed=False):
        """Shortcut to create a token with random key/secret."""
        token = self.create(consumer=consumer, 
                                            token_type=token_type, 
                                            timestamp=timestamp,
                                            scope=scope,
                                            user=user,
                                            callback=callback,
                                            callback_confirmed=callback_confirmed,
                                            key=uuid.uuid4().hex,
                                            secret=get_random_string(length=SECRET_SIZE))

        return token



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

import oauth10a as oauth

try:
    from functools import update_wrapper
except ImportError:
    from django.utils.functional import update_wrapper  # Python 2.3, 2.4 fallback.

from django.utils.translation import ugettext as _

from .responses import *
from .utils import initialize_server_request, send_oauth_error, get_oauth_request, verify_oauth_request
from .consts import OAUTH_PARAMETERS_NAMES
from .store import get_store_singleton, InvalidTokenError, InvalidConsumerError
from functools import wraps

def DoOAuthCheck(request, scope_name, *args, **kwargs):
    oauth_request = get_oauth_request(request)
    if oauth_request is None:
        return False, GetInvalidParamsResponse(), None

    try:
        consumer = get_store_singleton().get_consumer(request, oauth_request, oauth_request['oauth_consumer_key'])
    except InvalidConsumerError:
        return False, GetInvalidConsumerResponse(), None

    try:
        token = get_store_singleton().get_access_token(request, oauth_request, consumer, oauth_request.get_parameter('oauth_token'))
    except InvalidTokenError:
        return False, send_oauth_error(oauth.Error(_('Invalid access token: %s') % oauth_request.get_parameter('oauth_token'))), None

    if not verify_oauth_request(request, oauth_request, consumer, token):
        return False, GetCouldNotVerifyOAuthRequestResponse(), None

    if bool(scope_name) and (not token.scope
                            or token.scope.name != scope_name):
        return False, GetInvalidScopeResponse(), None

    return True, None, token.user

class CheckOauth(object):
    """
    Decorator that checks that the OAuth parameters passes the given test, raising
    an OAuth error otherwise. If the test is passed, the view function
    is invoked.

    We use a class here so that we can define __get__. This way, when a
    CheckOAuth object is used as a method decorator, the view function
    is properly bound to its instance.
    """
    def __init__(self, scope_name=None):
        self.scope_name = scope_name

    def __new__(cls, arg=None):
        if not callable(arg):
            return super(CheckOauth, cls).__new__(cls)
        else:
            obj =  super(CheckOauth, cls).__new__(cls)
            obj.__init__()
            return obj(arg)

    def __call__(self, view_func):

        @wraps(view_func)
        def wrapped_view(request, *args, **kwargs):
            ok, err_view, token_user = DoOAuthCheck(request, self.scope_name, *args, **kwargs)
            if not ok:
                return err_view
            if token_user:
                request.user = token_user
            return view_func(request, *args, **kwargs)

        return wrapped_view


oauth_required = CheckOauth
